@@ -1,7 +1,7 @@
 from interactions.ext import Base, Version, VersionAuthor
 
 version: Version = Version(
-    version="2.0.0",
+    version="2.0.1",
     author=VersionAuthor(
         name="Toricane",
         email="prjwl028@gmail.com",
@@ -11,8 +11,8 @@ version: Version = Version(
 base = Base(
     name="dinteractions-Paginator",
     version=version,
-    description="Unofficial discord-interactions multi page embed handler",
+    description="Official interactions.py paginator",
     link="https://github.com/Toricane/dinteractions-Paginator",
     packages=["interactions.ext.paginator"],
-    requirements=["discord-py-interactions>=4.2.0", "interactions-wait-for"],
+    requirements=["discord-py-interactions>=4.2.0", "interactions-wait-for>=1.0.4"],
 )
